@@ -8,7 +8,7 @@
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 	http://etersoft.ru/natspec
 
-    $Id: natspec.h,v 1.13 2005/02/23 15:03:27 lav Exp $
+    $Id: natspec.h,v 1.16 2005/02/26 15:23:06 lav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -94,23 +94,27 @@ const char * natspec_get_charset_by_locale(const int type,
  * Returns: a newly allocated nul-terminated string,
  * 	which must be freed with free(). Otherwise NULL.
  */
-char *natspec_convert(const char *in_str,
+ 
+/* Translaterate inconvenient symbols */
+char *natspec_convert_with_translit(const char *in_str,
 	const char *tocode, const char *fromcode);
 
+/* Returns NULL is conversion is failed */
+char *natspec_convert(const char *in_str,
+	const char *tocode, const char *fromcode);
 
 /************* Helper functions *******************/
 
 /*
  * Specially for mount-like command.
- * Realloc memory for options and add to it
- * need i18n params for fs type
+ * Add need i18n params for fs type to mount options
+ * and return new string
  * Params:
- *  fs - filesystem type
- *  options - pointer to pointer at options string
- * NB: we do free(*options) after new string is allocated
+ *  fs      - filesystem type string
+ *  options - already exist options string
  * Returns: new allocated string with enriched options
  */
-char * natspec_enrich_fs_options(const char* fs, char **options);
+char * natspec_get_enriched_fs_options(const char* fs, const char *options);
 
 /*
  * Returns codepage for charset
